<?php
namespace Datamints\DatamintsPiwik\Command;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2015 Mathias Wasserthal <m.wasserthal@datamints.com>,, datamints GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Controller for command to export data to Piwik.
 *
 * @package datamints_piwik
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class PiwikConnectCommandController extends \TYPO3\CMS\Extbase\Mvc\Controller\CommandController {

	/**
	 * Instance of the configuration manager to access TypoScript
	 *
	 * @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface
	 * @inject
	 */
	protected $configurationManager;

	/**
	 * Service to export data to Piwik
	 *
	 * @var \Datamints\DatamintsPiwik\Service\PiwikExportService
	 * @inject
	 */
	protected $piwikExportService;

	/**
	 * Settings from TypoScript
	 *
	 * @var array
	 */
	protected $settings = array();

	/**
	 * Initialize the CommandController.
	 *
	 * @param int $idsite The piwik website id
	 * @param string $host The piwik host
	 * @param string $apikey Password to authenticate in Piwik API requests
	 * @param int $rootpid Root page id (empty, if no microsite)
	 */
	protected function initialize($idsite = NULL, $host = NULL, $apikey = NULL, $rootpid = NULL) {
		$this->settings = $this->configurationManager->getConfiguration(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface::CONFIGURATION_TYPE_SETTINGS, 'datamintsPiwik', 'pi1');

		// Override TypoScript settings.
		if ($idsite) {
			$this->settings['idsite'] = $idsite;
		}
		if ($host) {
			$this->settings['host'] = $host;
		}
		if ($apikey) {
			$this->settings['apikey'] = $apikey;
		}
		if ($rootpid) {
			$this->settings['rootpid'] = $rootpid;
		}

		$this->piwikExportService->setSettings($this->settings);
	}

	/**
	 * Update all events to be processed. This ensures no old sys_log entries are exported at first export.
	 */
	public function invalidateCommand() {
		$this->initialize(NULL, NULL, NULL, 1);
		$this->piwikExportService->invalidate();
	}

	/**
	 * Export internal notes that have not been exported.
	 *
	 * @param int $rootpid Id of rootpage (empty, if no microsite)
	 * @param int $idsite Piwik Website id (empty, if no microsite)
	 * @param string $host Piwik host (empty, if no microsite)
	 * @param string $apikey Password to authenticate in piwik API requests (empty, if no microsite)
	 */
	public function exportSysNotesCommand($rootpid = NULL, $idsite = NULL, $host = NULL, $apikey = NULL) {
		$this->initialize($idsite, $host, $apikey, $rootpid);
		$this->piwikExportService->export(TRUE);
	}

	/**
	 * Export sys_log entries that have not been exported.
	 *
	 * @param int $rootpid Id of rootpage (empty, if no microsite)
	 * @param int $idsite Piwik Website id (empty, if no microsite)
	 * @param string $host Piwik host (empty, if no microsite)
	 * @param string $apikey Password to authenticate in piwik API requests (empty, if no microsite)
	 */
	public function exportSysLogsCommand($rootpid = NULL, $idsite = NULL, $host = NULL, $apikey = NULL) {
		$this->initialize($idsite, $host, $apikey, $rootpid);
		$this->piwikExportService->export(FALSE);
	}

}
