<?php
namespace Datamints\DatamintsPiwik\Hooks;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2015 Eva Rieger <e.rieger@datamints.com>, datamints GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * Hook for EXT:indexed_search to track the search in Piwik.
 *
 * @package datamints_piwik
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class IndexedSearchHook {

	/**
	 * The default Piwik call
	 */
	const TRACK_PAGEVIEW_CALL = '_paq.push([\'trackPageView\']);';

	/**
	 * Flag that signals that the default Piwik call should be replaced
	 *
	 * @var boolean
	 */
	private static $replace;

	/**
	 * Hook method called for display of search results;
	 * this is where we add the Piwik tracking call.
	 *
	 * @param array $searchWords
	 * @param string $resultData
	 * @param int $freeIndexUid
	 * @return string
	 */
	function getDisplayResults($searchWords, $resultData, $freeIndexUid = -1) {
		// Get the current content.
		$content = $this->pObj->getDisplayResults($searchWords, $resultData, $freeIndexUid = -1);

		// Get TypoScript settings.
		/** @var \TYPO3\CMS\Extbase\Object\ObjectManager $objectManager */
		$objectManager = GeneralUtility::makeInstance('TYPO3\\CMS\\Extbase\\Object\\ObjectManager');
		/** @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface $configurationManager */
		$configurationManager = $objectManager->get('TYPO3\\CMS\\Extbase\\Configuration\\ConfigurationManagerInterface');
		$settings = $configurationManager->getConfiguration(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface::CONFIGURATION_TYPE_SETTINGS, 'DatamintsPiwik', 'Pi1');
		if (!$settings['trackIndexedSearch']) {
			return $content;
		}

		// Get search keywords.
		$keyword = array();
		foreach ($searchWords as $entry) {
			$keyword[] = $entry['sword'];
		}
		$keyword = implode(' ', $keyword);

		// Add trackSiteSearch method call.
		$resultCount = isset($resultData['count']) ? $resultData['count'] : 0;
		$content .= <<<EOT
<script type="text/javascript">
var _paq = _paq || [];
_paq.push(['trackSiteSearch', '{$keyword}', false, {$resultCount}]);
</script>
EOT;
		self::$replace = TRUE;

		return $content;
	}

	/**
	 * Post-process the output and place our Piwik call in the page.
	 *
	 * @param array $params Parameters of the hook
	 * @param \TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController $parentObj Calling object
	 */
	function contentPostProcOutput($params, &$parentObj) {
		if (self::$replace) {
			$parentObj->content = str_replace(self::TRACK_PAGEVIEW_CALL, '', $parentObj->content);
		}
	}

}
