<?php
namespace Datamints\DatamintsPiwik\Service;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2015 Mathias Wasserthal <m.wasserthal@datamints.com>, datamints GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * Base class for all Piwik services.
 *
 * @package datamints_piwik
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
abstract class PiwikConnectService {

	/**
	 * Persistence manager for object handling
	 *
	 * @var \TYPO3\CMS\Extbase\Persistence\Generic\PersistenceManager
	 * @inject
	 */
	var $persistenceManager;

	/**
	 * Configuration manager for access to TypoScript
	 *
	 * @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManager
	 * @inject
	 */
	var $configurationManager;

	/**
	 * Piwik utility class for making API calls
	 *
	 * @var \Datamints\DatamintsPiwik\Domain\Repository\PiwikRepository
	 * @inject
	 */
	var $piwikRepository;

	/**
	 * Settings from TypoScript
	 *
	 * @var array
	 */
	protected $settings = array();

	/**
	 * The TYPO3 database connection
	 *
	 * @var \TYPO3\CMS\Core\Database\DatabaseConnection
	 */
	protected $db;

	/**
	 * Set settings array.
	 *
	 * @param array $settings
	 */
	public function setSettings($settings) {
		$this->settings = $settings;
		$this->piwikRepository->setSettings($settings);
	}

	/**
	 * Initalize the service.
	 *
	 */
	protected function initialize() {

		if (!$this->db) {
			$this->db = $GLOBALS['TYPO3_DB'];
		}
	}

}
